@@ -36,7 +36,10 @@ fn main() {
             .and_then(|res| res.json())
             .ok();
         let text = match res.map(|r| r.result.len()) {
-            Some(0) | None => String::new(),
+            Some(0) | None => {
+                println!("");
+                continue;
+            }
             Some(len) => len.to_string(),
         };
         println!(r#"{{"text": "{}", "class": "{}"}}"#, text, class());
